@@ -19,6 +19,7 @@ from typing import List, Optional, Union
 import git
 import numpy as np
 import pandas as pd
+from nowcasting_datamodel.models.pv import providers, pv_output, solar_sheffield_passiv
 from pathy import Pathy
 from pydantic import BaseModel, Field, root_validator, validator
 
@@ -27,7 +28,6 @@ from nowcasting_dataset.consts import (
     DEFAULT_N_GSP_PER_EXAMPLE,
     DEFAULT_N_PV_SYSTEMS_PER_EXAMPLE,
     NWP_VARIABLE_NAMES,
-    PV_PROVIDERS,
     SAT_VARIABLE_NAMES,
 )
 from nowcasting_dataset.dataset.split import split
@@ -188,12 +188,15 @@ class PVFiles(BaseModel):
         description="Tthe CSV files describing each PV system.",
     )
 
-    label: str = Field("pvoutput", description="Label of where the pv data came from")
+    label: str = Field(pv_output, description="Label of where the pv data came from")
 
     @validator("label")
     def v_label0(cls, v):
         """Validate 'label'"""
-        assert v in PV_PROVIDERS
+        if v not in providers:
+            message = f"provider {v} not in {providers}"
+            logger.error(message)
+            raise Exception(message)
         return v
 
 
@@ -250,7 +253,7 @@ class PV(DataSourceMixin, StartEndDatetimeMixin):
                 "Loading pv files the old way, and moving them the new way. "
                 "Please update configuration file"
             )
-            label = "pvoutput" if "pvoutput" in v.pv_filename.lower() else "passiv"
+            label = pv_output if "pvoutput" in v.pv_filename.lower() else solar_sheffield_passiv
             pv_file = PVFiles(
                 pv_filename=v.pv_filename, pv_metadata_filename=v.pv_metadata_filename, label=label
             )
