@@ -2,6 +2,12 @@
 from nowcasting_dataset.data_sources.data_source import DataSource  # noqa: F401
 from nowcasting_dataset.data_sources.gsp.gsp_data_source import GSPDataSource
 from nowcasting_dataset.data_sources.nwp.nwp_data_source import NWPDataSource
+
+# We must import OpticalFlowDataSource *after* SatelliteDataSource,
+# otherwise we get circular import errors!
+from nowcasting_dataset.data_sources.optical_flow.optical_flow_data_source import (
+    OpticalFlowDataSource,
+)
 from nowcasting_dataset.data_sources.pv.pv_data_source import PVDataSource
 from nowcasting_dataset.data_sources.satellite.satellite_data_source import (
     HRVSatelliteDataSource,
@@ -18,6 +24,7 @@ MAP_DATA_SOURCE_NAME_TO_CLASS = {
     "pv": PVDataSource,
     "satellite": SatelliteDataSource,
     "hrvsatellite": HRVSatelliteDataSource,
+    "opticalflow": OpticalFlowDataSource,
     "nwp": NWPDataSource,
     "gsp": GSPDataSource,
     "topographic": TopographicDataSource,
